# Turrican Rotary Saw

![](https://turrican.uraanikaivos.com/rotarysawturrican.png)

Turrican turns into a impervious silver rotary saw in combat. Rotary Saw is my personal hack and quick scripts collection 
for whatever I try next.
